from django.template import Template, Context, TemplateSyntaxError
from django.test import TestCase


def render_string(tag_code, context=None):
    # Helper function to render template tags
    t = Template("{% load social_widgets %}" + tag_code)
    return t.render(Context(context or {}))


class BaseTests(TestCase):
    def test_multiple_widgets_with_single_external_javascript(self):
        html = render_string(
            "{% social_widget_render 'facebook/likebox.html' %}"
            "{% social_widget_render 'facebook/follow_button.html' %}"
        )
        self.assertEqual(html.count('facebook-jssdk'), 1)

    def test_language(self):
        html = render_string(
            "{% social_widget_render 'facebook/likebox.html'"
            " language='en-us' %}"
        )
        self.assertIn('en_US', html)


class IncorrectDataTest(TestCase):
    def test_incorrect_template(self):
        html = render_string(
            "{% social_widget_render "
            "'non_existent_dir/non_existent_template.html' %}"
        )
        self.assertEqual(html, "")

    def test_tag_without_parameters(self):
        self.assertRaises(TemplateSyntaxError,
                          render_string, "{% social_widget_render %}")

    def test_malformed_arguments(self):
        self.assertRaises(TemplateSyntaxError,
                          render_string, "{% social_widget_render x==2 %}")


class TestToDataStringWithDefaultFilter(TestCase):
    def test_true(self):
        html = render_string("{{ True|to_data_string_with_default }}")
        self.assertEqual(html, "true")

    def test_false(self):
        html = render_string("{{ False|to_data_string_with_default }}")
        self.assertEqual(html, "false")

    def test_value(self):
        html = render_string("{{ 'value'|to_data_string_with_default }}")
        self.assertEqual(html, "value")

    def test_blank(self):
        html = render_string("{{ None|to_data_string_with_default }}")
        self.assertEqual(html, "")

    def test_default_arg(self):
        html = render_string(
            "{{ None|to_data_string_with_default:'default' }}"
        )
        self.assertEqual(html, "default")


import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-social-widgets',
    version='0.1.2',
    packages=['social_widgets'],
    include_package_data=True,
    license='MIT License',
    description='Django app for easy embedding social network widgets and '
                'plugins into your site. Supports Facebook, Twitter, Google+, '
                'YouTube, Instagram and Pinterest.',
    long_description=README,
    keywords='Django, social network, template, facebook, twitter',
    url='https://github.com/creafz/django-social-widgets',
    download_url=
    'https://github.com/creafz/django-social-widgets/tarball/0.1.2',
    author='Alex Parinov',
    author_email='creafz@gmail.com',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=["django>=1.5"],
)